@@ -22,6 +22,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
+#include "common_indep.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -56,6 +57,7 @@ extern "C" {
 
 void log_debug (const char *fmt, ...) __attribute__ ((format (printf,1,2)));
 void log_error (const char *fmt, ...) __attribute__ ((format (printf,1,2)));
+
 void log_vdebug (const char *fmt, va_list a);
 void log_debug_w32 (int w32err, const char *fmt,
                     ...) __attribute__ ((format (printf,2,3)));
@@ -77,6 +79,15 @@ const char *anonstr (const char *data);
 #define log_trace(format, ...) if ((opt.enable_debug & DBG_TRACE)) \
   log_debug("TRACE/" format, ##__VA_ARGS__)
 
+#define log_warn(format, ...) if (opt.enable_debug) \
+  log_debug("WARNING/" format, ##__VA_ARGS__)
+
+#define log_dbg(format, ...) if (opt.enable_debug) \
+  log_debug("%s:%s:" format, SRCNAME, __func__, ##__VA_ARGS__)
+
+#define log_err(format, ...) if (opt.enable_debug) \
+  log_debug("%s:%s:" format, SRCNAME, __func__, ##__VA_ARGS__)
+
 #define gpgol_release(X) \
 { \
   if (X && opt.enable_debug & DBG_MEMORY) \
