@@ -870,8 +870,10 @@ public:
         if (!key.canEncrypt() || key.isRevoked() ||
             key.isExpired() || key.isDisabled() || key.isInvalid())
           {
-            log_data ("%s:%s: Invalid key for %s. no internal encryption",
-                       SRCNAME, __func__, anonstr (recip.c_str ()));
+            log_data ("%s:%s: Invalid [%s%s%s%s%s] key for %s. no internal encryption",
+                       SRCNAME, __func__, key.canEncrypt()?"E":".", key.isRevoked()?"R":".",
+                        key.isExpired()?"X":".", key.isDisabled()?"D":".",
+                        key.isInvalid()?"I":".", anonstr (recip.c_str ()));
             TRETURN std::vector<GpgME::Key>();
           }
 
